Encoding: UTF-8
Package: genSurv
Type: Package
Version: 1.0.6
Date: 2026-04-05
Title: Generating Multi-State Survival Data
Authors@R: c(
	person(
		given = "Artur",
		family = "Araujo",
		role = c("aut", "cre"),
		email = "artur.stat@gmail.com",
		comment = c(ORCID = "0000-0003-1419-4208")
	),
	person(
		given = "Luis",
		family = "Meira-Machado",
		role = "aut",
		email = "lmachado@math.uminho.pt",
		comment = c(ORCID = "0000-0002-8577-7665")
	),
	person(
		given = "Susana",
		family = "Faria",
		role = "aut",
		email = "sfaria@math.uminho.pt",
		comment = c(ORCID = "0000-0001-8014-9902")
	) )
Depends: R (>= 2.12.0)
Suggests: survival
Description: Generation of survival data with one (binary)
  time-dependent covariate.  Generation of survival data arising
  from a progressive illness-death model.
License: GPL-3
URL: https://github.com/arturstat/genSurv
BugReports: https://github.com/arturstat/genSurv/issues
LazyLoad: yes
NeedsCompilation: yes
Packaged: 2026-04-05 16:48:33 UTC; User
Author: Artur Araujo [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1419-4208>),
  Luis Meira-Machado [aut] (ORCID:
    <https://orcid.org/0000-0002-8577-7665>),
  Susana Faria [aut] (ORCID: <https://orcid.org/0000-0001-8014-9902>)
Maintainer: Artur Araujo <artur.stat@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-05 17:30:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-08 01:04:39 UTC; unix
Archs: genSurv.so.dSYM

useDynLib(genSurv, .registration=TRUE)
importFrom("stats", rexp, runif)
export(genCMM, genCPHM, genTDCM, genTHMM)
export(as.CMM, as.TDCM, as.THMM)
export(is.CMM, is.TDCM, is.THMM)
S3method(as.CMM, default)
S3method(as.CMM, CMM)
S3method(as.CMM, TDCM)
S3method(as.CMM, THMM)
S3method(as.TDCM, default)
S3method(as.TDCM, TDCM)
S3method(as.TDCM, CMM)
S3method(as.TDCM, THMM)
S3method(as.THMM, default)
S3method(as.THMM, THMM)
S3method(as.THMM, CMM)
S3method(as.THMM, TDCM)

# genSurv
Generating Multi-State Survival Data.

## Description
The **genSurv** software permits to generate data with one binary time-dependent covariate and data stemming from a progressive illness-death model.

## Installation
If you want to use the release version of the **genSurv** package, you can install the package from CRAN as follows:
```r
install.packages(pkgs="genSurv");
```
If you want to use the development version of the **genSurv** package, you can install the package from GitHub via the [**remotes**](https://remotes.r-lib.org) package:
```r
remotes::install_github(
  repo="arturstat/genSurv",
  build=TRUE,
  build_manual=TRUE
);
```

## Authors
Artur Araújo, Luís Meira-Machado <lmachado@math.uminho.pt> \
and Susana Faria <sfaria@math.uminho.pt> \
Maintainer: Artur Araújo <artur.stat@gmail.com>

## Funding
This research was financed by **FEDER** Funds through *Programa Operacional Factores de Competitividade* -- **COMPETE** and by Portuguese Funds through **FCT** -- *Fundação para a Ciência e a Tecnologia*, in the form of grants PTDC/MAT/104879/2008 and Est-C/MAT/UI0013/2011.

## References
Anderson, P.K., Gill, R.D. (1982). Cox's regression model for counting processes: a large sample study. *Annals of Statistics*, **10**(4), 1100-1120. [doi:10.1214/aos/1176345976](https://doi.org/10.1214/aos/1176345976)

Cox, D.R. (1972). Regression models and life tables. *Journal of the Royal Statistical Society: Series B*, **34**(2), 187-202. [doi:10.1111/j.2517-6161.1972.tb00899.x](https://doi.org/10.1111/j.2517-6161.1972.tb00899.x)

Jackson, C. (2011). Multi-State Models for Panel Data: The msm Package for R. *Journal of Statistical Software*, **38**(8), 1–28. [doi:10.18637/jss.v038.i08](https://doi.org/10.18637/jss.v038.i08)

Johnson, M. E. (1987). *Multivariate Statistical Simulation*, John Wiley and Sons.

Johnson, N., Kotz, S. (1972). *Distribution in statistics: continuous multivariate distributions*, John Wiley and Sons.

Lu J., Bhattacharya G. (1990). Some new constructions of bivariate weibull models. *Annals of Institute of Statistical Mathematics*, **42**(3), 543-559. [doi:10.1007/BF00049307](https://doi.org/10.1007/BF00049307)

Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. *Statistical Methods in Medical Research*, **18**(2), 195-222. [doi:10.1177/0962280208092301](https://doi.org/10.1177/0962280208092301)

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. *Communications in Statistics - Simulation and Computation*, **43**(5), 929-946. [doi:10.1080/03610918.2012.718841](https://doi.org/10.1080/03610918.2012.718841)

Meira-Machado, L., Roca-Pardiñas, J. (2011). p3state.msm: Analyzing Survival Data from an Illness-Death Model. *Journal of Statistical Software*, **38**(3), 1-18. [doi:10.18637/jss.v038.i03](https://doi.org/10.18637/jss.v038.i03)

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. *Biometrical Journal*, **61**(2), 245–263. [doi:10.1002/bimj.201700200](https://doi.org/10.1002/bimj.201700200)

Therneau, T.M., Grambsch, P.M. (2000). *Modelling survival data: Extending the Cox Model*, New York: Springer.

genTDCM <- function(n, dist, corr, dist.par, model.cens, cens.par, beta, lambda) {
	if (n <= 0) {stop("Argument 'n' must be greater than 0", call.=FALSE);}
	if ( !( dist %in% c("weibull", "exponential") ) ) {stop("Argument 'dist' must be one of 'weibull' or 'exponential'", call.=FALSE);}
	if (dist == "weibull") {
		if (corr <= 0 | corr > 1) {stop("Argument 'corr' with 'dist=weibull' must be greater than 0 and lower or equal to 1", call.=FALSE);}
		if (length(dist.par) != 4) {stop("Argument 'dist.par' with 'dist=weibull' must be a vector with lenght 4", call.=FALSE);}
		if (dist.par[1] <= 0 | dist.par[2] <= 0 | dist.par[3] <= 0 | dist.par[4] <= 0) {stop("Argument 'dist.par' must be greater than 0", call.=FALSE);}
	} else if (dist == "exponential") {
		if (corr < -1 | corr > 1) {stop("Argument 'corr' with dist='exponential' must be greater or equal to -1 and lower or equal to 1", call.=FALSE);}
		if (length(dist.par) != 2) {stop("Argument 'dist.par' with 'dist=exponential' must be a vector with lenght 2", call.=FALSE);}
		if (dist.par[1] <= 0 | dist.par[2] <= 0) {stop("Argument 'dist.par' must be greater than 0", call.=FALSE);}
	}
	if ( !( model.cens %in% c("uniform", "exponential") ) ) {stop("Argument 'model.cens' must be one of 'uniform' or 'exponential'", call.=FALSE);}
	if (cens.par <= 0) {stop("Argument 'cens.par' must be greater than 0", call.=FALSE);}
	if (length(beta) != 2) {stop("Argument 'beta' length must be a vector with length 2", call.=FALSE);}
	if (lambda <= 0) {stop("Argument 'lambda' must be greater than 0", call.=FALSE);}
	b <- dgBIV(n, dist, corr, dist.par);
	if (model.cens == "uniform") {
		rfunc <- runifcens;
	} else if (model.cens == "exponential") {rfunc <- rexpcens;}
	mat <- matrix(ncol=6,nrow=1);
	for (k in 1:n) {
		status <- 1;
		u <- runif(1, 0, 1);
		z1 <- b[k,2];
		c <- rfunc(1, cens.par);
		if ( u < 1-exp( -lambda*b[k,1]*exp(beta[1]*z1) ) ) {
			t <- -log(1-u)/( lambda*exp(beta[1]*z1) );
			z2 <- 0;
		} else {
			t <- -( log(1-u)+lambda*b[k,1]*exp(beta[1]*z1)*( 1-exp(beta[2]) ) )/( lambda*exp(beta[1]*z1+beta[2]) );
			x12 <- b[k,1];
			z2 <- 1;
		}
		time <- min(t, c);
		ifelse(t > c, status <- 0, status <- 1);
		if ( u < 1-exp( -lambda*b[k,1]*exp(beta[1]*z1) ) ) {
			aux1 <- c(k, 0, time, status, z1, 0);
			mat <- rbind(mat, aux1);
		} else {
			if (c > x12) {
				aux1 <- c(k, 0, x12, 0, z1, 0);
				mat <- rbind(mat, aux1);
				aux2 <- c(k, x12, time, status, z1, 1);
				mat <- rbind(mat, aux2);
			} else {
				aux1 <- c(k, 0, time, status, z1, 0);
				mat <- rbind(mat, aux1);
			}
		}
	}
	data <- data.frame(mat, row.names=NULL);
	names(data) <- c("id", "start", "stop", "event", "covariate", "tdcov");
	data <- data[-1,];
	row.names(data) <- as.integer( 1:nrow(data) );
	class(data) <- c(class(data), "TDCM");
	return(data);
} # genTDCM

is.TDCM <- function(x) {
	return( is.data.frame(x) & inherits(x, "TDCM") );
} # is.TDCM

as.TDCM <- function(x) {
	UseMethod("as.TDCM");
} # as.TDCM

as.TDCM.default <- function(x) {
	stop(gettextf( "cannot coerce class '%s' into class 'TDCM'", deparse( class(x) ) ), domain = NA);
} # as.TDCM.default

as.TDCM.TDCM <- function(x) {
	if ( !is.TDCM(x) ) {stop("'x' must be of class 'TDCM'");}
	return(x);
} # as.TDCM.TDCM

as.TDCM.CMM <- function(x) {
	if ( !is.CMM(x) ) {stop("'x' must be of class 'CMM'");}
	data <- cbind(x$id, x$start, x$stop, x$event, x$covariate, x$trans);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("id", "start", "stop", "event", "covariate", "trans");
	data2 <- matrix(ncol=6, nrow=1);
	i <- 1;
	while ( i <= (nrow(data)-1) ) {
		if (data[i,1] == data[i+1,1] & data[i,4] == 0 & data[i+1,4]==0) {
			aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 0);
			data2 <- rbind(data2, aux1);
			i <- i+2;
		}
		if (i <= (nrow(data)-1) & data[i,6]==1 & data[i,4]==1) {
			aux1 <- c(data[i,1], 0, data[i,3], 1, data[i,5], 0);
			data2 <- rbind(data2, aux1);
			i <- i+2;
		}
		if (i <= (nrow(data)-1) & data[i,1] == data[i+1,1] & data[i,4] == 0 & data[i+1,4] == 1) {
			if (data[i+2,4] == 0) {
				aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 0);
				aux2 <- c(data[i,1], data[i,3], data[i+2,3], 0, data[i,5], 1);
				data2 <- rbind(data2, aux1, aux2);
			}
			if (data[i+2,4] == 1) {
				aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 0);
				aux2 <- c(data[i,1], data[i,3], data[i+2,3], 1, data[i,5], 1);
				data2 <- rbind(data2, aux1, aux2);
			}
			i <- i+3;
		}
	}
	data2 <- data.frame(data2, row.names=NULL);
	names(data2) <- c("id", "start", "stop", "event", "covariate", "tdcov");
	data2 <- data2[-1,];
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "TDCM");
	return(data2);
} # as.TDCM.CMM

as.TDCM.THMM <- function(x) {
	if ( !is.THMM(x) ) {stop("'x' must be of class 'THMM'");}
	data <- cbind(x$PTNUM, x$time, x$state, x$covariate);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("PTNUM", "time", "state", "covariate");
	data2 <- matrix(ncol=6, nrow=1);
	i <- 1;
	while( i <= nrow(data) ) {
		if (data[i,3] == data[i+1,3] & data[i+1,3] == 1) {
			aux <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 0);
			data2 <- rbind(data2, aux);
			i <- i+2;
		} else {
			if (data[i,3] == 1 & data[i+1,3] == 3) {
				aux <- c(data[i,1], 0, data[i+1,2], 1, data[i,4], 0);
				data2 <- rbind(data2, aux);
				i <- i+2;
			} else {
				aux <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 0);
				data2 <- rbind(data2, aux);
				i <- i+2;
				if (data[i,3] == 2) {
					aux <- c(data[i,1], data[i-1,2], data[i,2], 0, data[i,4], 1);
					data2 <- rbind(data2, aux);
					i <- i+1;
				} else {
					aux <- c(data[i,1], data[i-1,2], data[i,2], 1, data[i,4], 1);
					data2 <- rbind(data2, aux);
					i <- i+1;
				}
			}
		}
	}
	data2 <- data.frame(data2, row.names=NULL);
	names(data2) <- c("id", "start", "stop", "event", "covariate", "tdcov");
	data2 <- data2[-1,];
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "TDCM");
	return(data2);
} # as.TDCM.THMM

genTHMM <- function(n, model.cens, cens.par, beta, covar, rate) {
	if (n <= 0) {stop("Argument 'n' must be greater than 0", call.=FALSE);}
	if ( !( model.cens %in% c("uniform", "exponential") ) ) {stop("Argument 'model.cens' must be one of 'uniform' or 'exponential'", call.=FALSE);}
	if (cens.par <= 0) {stop("Argument 'cens.par' must be greater than 0", call.=FALSE);}
	if (length(beta) != 3) {stop("Argument 'beta' length must be a vector with length 3", call.=FALSE);}
	if (covar <= 0) {stop("Argument 'covar' must be greater than 0", call.=FALSE);}
	if (length(rate) != 3) {stop("Argument 'rate' must be a vector with length 3", call.=FALSE);}
	if (model.cens == "uniform") {
		rfunc <- runifcens;
	} else if (model.cens == "exponential") {rfunc <- rexpcens;}
	mat <- matrix(ncol=4, nrow=1);
	for (k in 1:n) {
		z1 <- runif(1, 0, covar);
		c <- rfunc(1, cens.par);
		rate12 <- rate[1]*exp(beta[1]*z1);
		rate13 <- rate[2]*exp(beta[2]*z1);
		rate23 <- rate[3]*exp(beta[3]*z1);
		t12 <- rexp(1, rate12);
		t13 <- rexp(1, rate13);
		t23 <- rexp(1, rate23);
		if (c < min(t12, t13) ) {
			aux1<-c(k,0,1,z1);
			mat<-rbind(mat,aux1);
			aux2<-c(k,c,1,z1);
			mat<-rbind(mat,aux2);
		} else {
			if (t13 < t12) {
				aux1 <- c(k, 0, 1, z1);
				mat <- rbind(mat, aux1);
				aux2 <- c(k, t13, 3, z1);
				mat <- rbind(mat, aux2);
			} else {
				aux1 <- c(k, 0, 1, z1);
				mat <- rbind(mat, aux1);
				aux2 <- c(k, t12, 2, z1);
				mat <- rbind(mat, aux2);
				if (c < t12+t23) {
					aux1 <- c(k, c, 2, z1);
					mat <- rbind(mat, aux1);
				} else {
					aux1 <- c(k ,t12+t23, 3, z1);
					mat <- rbind(mat, aux1);
				}
			}
		}
	}
	data <- data.frame(mat, row.names=NULL);
	names(data) <- c("PTNUM", "time", "state", "covariate");
	data <- data[-1,];
	row.names(data) <- as.integer( 1:nrow(data) );
	class(data) <- c(class(data), "THMM");
	return(data);
} # genTHMM

is.THMM <- function(x) {
	return( is.data.frame(x) & inherits(x, "THMM") );
} # is.THMM

as.THMM <- function(x) {
	UseMethod("as.THMM");
} # as.THMM

as.THMM.default <- function(x) {
	stop(gettextf( "cannot coerce class '%s' into class 'THMM'", deparse( class(x) ) ), domain = NA);
} # as.THMM.default

as.THMM.THMM <- function(x) {
	if ( !is.THMM(x) ) stop("'x' must be of class 'THMM'");
	return(x);
} # as.THMM.THMM

as.THMM.CMM <- function(x) {
	if ( !is.CMM(x) ) stop("'x' must be of class 'CMM'");
	data <- cbind(x$id, x$start, x$stop, x$event, x$covariate, x$trans);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("id", "start", "stop", "event", "covariate", "trans");
	data2 <- matrix(ncol=4, nrow=1);
	i <- 1;
	while ( i <= (nrow(data)-1) ) {
		if (data[i,1] == data[i+1,1] & data[i,4] == 0 & data[i+1,4] == 0) {
			aux1 <- c(data[i,1], 0, 1, data[i,5]);
			aux2 <- c(data[i,1], data[i,3], 1, data[i,5]);
			data2 <- rbind(data2, aux1, aux2);
			i <- i+2;
		}
		if (i <= (nrow(data)-1) & data[i,6] == 1 & data[i,4] == 1) {
			aux1 <- c(data[i,1], 0, 1, data[i,5]);
			aux2 <- c(data[i,1], data[i,3], 3, data[i,5]);
			data2 <- rbind(data2, aux1, aux2);
			i <- i+2;
		}
		if (i <= (nrow(data)-1) & data[i,1] == data[i+1,1] & data[i,4] == 0 & data[i+1,4] == 1) {
			if (data[i+2,4] == 0) {
				aux1 <- c(data[i,1], 0, 1, data[i,5]);
				aux2 <- c(data[i,1], data[i,3], 2, data[i,5]);
				aux3 <- c(data[i,1], data[i+2,3], 2, data[i,5]);
				data2 <- rbind(data2, aux1, aux2, aux3);
			}
			if (data[i+2,4] == 1) {
				aux1 <- c(data[i,1], 0, 1, data[i,5]);
				aux2 <- c(data[i,1], data[i,3], 2, data[i,5]);
				aux3 <- c(data[i,1], data[i+2,3], 3, data[i,5]);
				data2 <- rbind(data2, aux1, aux2, aux3);
			}
			i <- i+3;
		}
	}
	data2 <- data.frame(data2, row.names=NULL);
	names(data2) <- c("PTNUM", "time", "state", "covariate");
	data2 <- data2[-1,];
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "THMM");
	return(data2);
} # as.THMM.CMM

as.THMM.TDCM <- function(x) {
	if ( !is.TDCM(x) ) stop("'x' must be of class 'TDCM'");
	data <- cbind(x$start, x$stop, x$event, x$covariate, x$tdcov);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("start", "stop", "event", "covariate", "tdcov");
	data2 <- data.frame();
	j <- 1;
	i <- 1;
	doente <- 1;
	ultimo <- 0;
	while ( i <= nrow(data) ) {
		if ( i == nrow(data) ) ultimo <- 1;
		if (ultimo == 0 & data[i,2] == data[i+1,1] & data[i+1,3] == 0) {
			data2[j,1] <- doente;
			data2[j,2] <- 0;
			data2[j,3] <- 1;
			data2[j,4] <- data[i,4];
			j <- j+1;
			data2[j,1] <- doente;
			data2[j,2] <- data[i,2];
			data2[j,3] <- 2;
			data2[j,4] <- data[i,4];
			j <- j+1;
			data2[j,1] <- doente;
			data2[j,2] <- data[i+1,2];
			data2[j,3] <- 2;
			data2[j,4] <- data[i,4];
			i <- i+2;
			j <- j+1;
			doente <- doente+1;
		} else {
			if (ultimo == 0 & data[i,2] == data[i+1,1] & data[i+1,3] == 1) {
				data2[j,1] <- doente;
				data2[j,2] <- 0;
				data2[j,3] <- 1;
				data2[j,4] <- data[i,4];
				j <- j+1;
				data2[j,1] <- doente;
				data2[j,2] <- data[i,2];
				data2[j,3] <- 2;
				data2[j,4] <- data[i,4];
				j <- j+1;
				data2[j,1] <- doente;
				data2[j,2] <- data[i+1,2];
				data2[j,3] <- 3;
				data2[j,4] <- data[i,4];
				i <- i+2;
				j <- j+1;
				doente <- doente+1;
			} else {
				if (data[i,3] == 1) {
					data2[j,1] <- doente;
					data2[j,2] <- 0;
					data2[j,3] <- 1;
					data2[j,4] <- data[i,4];
					j <- j+1;
					data2[j,1] <- doente;
					data2[j,2] <- data[i,2];
					data2[j,3] <- 3;
					data2[j,4] <- data[i,4];
					i <- i+1;
					j <- j+1;
					doente <- doente+1;
				} else {
					data2[j,1] <- doente;
					data2[j,2] <- 0;
					data2[j,3] <- 1;
					data2[j,4] <- data[i,4];
					j <- j+1;
					data2[j,1] <- doente;
					data2[j,2] <- data[i,2];
					data2[j,3] <- 1;
					data2[j,4] <- data[i,4];
					i <- i+1;
					j <- j+1;
					doente <- doente+1;
				}
			}
		}
	}
	names(data2) <- c("PTNUM", "time", "state", "covariate");
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "THMM");
	return(data2);
} # as.THMM.TDCM

genCMM <- function(n, model.cens, cens.par, beta, covar, rate) {
	if (n <= 0) {stop("Argument 'n' must be greater than 0", call.=FALSE);}
	if ( !( model.cens %in% c("uniform", "exponential") ) ) {stop("Argument 'model.cens' must be one of 'uniform' or 'exponential'", call.=FALSE);}
	if (cens.par <= 0) {stop("Argument 'cens.par' must be greater than 0", call.=FALSE);}
	if (length(beta) != 3) {stop("Argument 'beta' length must be a vector with length 3", call.=FALSE);}
	if (covar <= 0) {stop("Argument 'covar' must be greater than 0", call.=FALSE);}
	if (length(rate) != 6) {stop("Argument 'rate' must be a vector with length 6", call.=FALSE);}
	if (model.cens == "uniform") {
		rfunc <- runifcens;
	} else if (model.cens == "exponential") {rfunc <- rexpcens;}
	mat <- matrix(ncol=6, nrow=1);
	for (k in 1:n) {
		z1 <- runif(1, 0, covar);
		c <- rfunc(1, cens.par);
		u <- runif(1, 0, 1);
		t12 <- ( -log(1-u)/( rate[1]* exp(beta[1]*z1) ) )^(1/ rate[2]);
		u <- runif(1, 0, 1);
		t13 <- ( -log(1-u)/ ( rate[3]* exp(beta[2]*z1) ) )^(1/ rate[4]);
		u <- runif(1, 0, 1);
		t23 <- ( -log(1-u)/ ( rate[5]* exp(beta[3]*z1) ) )^(1/ rate[6]);
		if (c < min(t12, t13) ) {
			aux1 <- c(k, 0, c, 0, z1, 1);
			mat <- rbind(mat, aux1);
			aux2 <- c(k, 0, c, 0, z1, 2);
			mat <- rbind(mat, aux2);
		} else {
			if (t13 < t12) {
				aux1 <- c(k, 0, t13, 1, z1, 1);
				mat <- rbind(mat, aux1);
				aux2 <- c(k, 0, t13, 0, z1, 2);
				mat <- rbind(mat, aux2);
			} else {
				aux1 <- c(k, 0, t12, 0, z1, 1);
				mat <- rbind(mat, aux1);
				aux2 <- c(k, 0, t12, 1, z1, 2);
				mat <- rbind(mat, aux2);
				if (c < t12+t23) {
					aux1 <- c(k, t12, c, 0, z1, 3);
					mat <- rbind(mat, aux1);
				} else {
					aux1 <- c(k, t12, t12+t23, 1, z1, 3);
					mat <- rbind(mat, aux1);
				}
			}
		}
	}
	data <- data.frame(mat, row.names=NULL);
	data <- data[-1,];
	names(data) <- c("id", "start", "stop", "event", "covariate", "trans");
	row.names(data) <- as.integer( 1:nrow(data) );
	class(data) <- c(class(data), "CMM");
	return(data);
} # genCMM

genCPHM <- function(n, model.cens, cens.par, beta, covar) {
	if (n <= 0) {stop("Argument 'n' must be greater than 0", call.=FALSE);}
	if ( !( model.cens %in% c("uniform", "exponential") ) ) {stop("Argument 'model.cens' must be one of 'uniform' or 'exponential'", call.=FALSE);}
	if (cens.par <= 0) {stop("Argument 'cens.par' must be greater than 0", call.=FALSE);}
	if (covar <= 0) {stop("Argument 'covar' must be greater than 0", call.=FALSE);}
	if (model.cens == "uniform") {
		rfunc <- runifcens;
	} else if (model.cens == "exponential") {rfunc <- rexpcens;}
	data <- matrix(data=0, ncol=3, nrow=n);
	for (k in 1:n) {
		status <- 1;
		z <- runif(1, 0, covar);
		c <- rfunc(1, cens.par);
		x <- rexp( 1, exp(beta*z) );
		time <- min(x, c);
		ifelse(x > c, status <- 0, status <- 1);
		data[k,] <- c(time, status, z);
	}
	data <- data.frame(data);
	names(data) <- c("time", "status", "covariate");
	row.names(data) <- as.integer( 1:nrow(data) );
	class(data) <- c(class(data), "CPHM");
	return(data);
} # genCPHM

is.CMM <- function(x) {
	return( is.data.frame(x) & inherits(x, "CMM") );
} # is.CMM

as.CMM <- function(x) {
	UseMethod("as.CMM");
} # as.CMM

as.CMM.default <- function(x) {
	stop(gettextf( "cannot coerce class '%s' into class 'CMM'", deparse( class(x) ) ), domain = NA);
} # as.CMM.default

as.CMM.CMM <- function(x) {
	if ( !is.CMM(x) ) {stop("'x' must be of class 'CMM'");}
	return(x);
} # as.CMM.CMM

as.CMM.TDCM <- function(x) {
	if ( !is.TDCM(x) ) {stop("'x' must be of class 'TDCM'");}
	data <- cbind(x$id, x$start, x$stop, x$event, x$covariate, x$tdcov);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("id", "start", "stop", "event", "covariate", "tdcov");
	data2 <- matrix(ncol=6, nrow=1);
	i <- 1;
	while ( i <= (nrow(data)-1) ) {
		if (data[i,1] != data[i+1,1] & data[i,4] == 0) {
			aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 1);
			aux2 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 2);
			data2 <- rbind(data2, aux1, aux2);
			i <- i+1;
		}
		if (i <= (nrow(data)-1) & data[i,1] != data[i+1,1] & data[i,4] == 1) {
			aux1 <- c(data[i,1], 0, data[i,3], 1, data[i,5], 1);
			aux2 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 2);
			data2 <- rbind(data2, aux1, aux2);
			i <- i+1;
		}
		if (i <= (nrow(data)-1) & data[i,1] == data[i+1,1] & data[i,4] == 0) {
			if (data[i+1,4] == 0) {
				aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 1);
				aux2 <- c(data[i,1], 0, data[i,3], 1, data[i,5], 2);
				aux3 <- c(data[i,1], data[i,3], data[i+1,3], 0, data[i,5], 3);
				data2 <- rbind(data2, aux1, aux2, aux3);
			} else if (data[i+1,4] == 1) {
				aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 1);
				aux2 <- c(data[i,1], 0, data[i,3], 1, data[i,5], 2);
				aux3 <- c(data[i,1], data[i,3], data[i+1,3], 1, data[i,5], 3);
				data2 <- rbind(data2, aux1, aux2, aux3);
			}
			i <- i+2;
		}
	}
	if ( i == nrow(data) ) {
		if (data[i,4] == 0) {
			aux1 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 1);
			aux2 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 2);
			data2 <- rbind(data2, aux1, aux2);
		} else if (data[i,4] == 1) {
			aux1 <- c(data[i,1], 0, data[i,3], 1, data[i,5], 1);
			aux2 <- c(data[i,1], 0, data[i,3], 0, data[i,5], 2);
			data2 <- rbind(data2, aux1, aux2);
		}
	}
	data2 <- data.frame(data2, row.names=NULL);
	names(data2) <- c("id", "start", "stop", "event", "covariate", "trans");
	data2 <- data2[-1,];
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "CMM");
	return(data2);
} # as.CMM.TDCM

as.CMM.THMM <- function(x) {
	if ( !is.THMM(x) ) {stop("'x' must be of class 'THMM'");}
	data <- cbind(x$PTNUM, x$time, x$state, x$covariate);
	data <- data.frame(data, row.names=NULL);
	names(data) <- c("PTNUM", "time", "state", "covariate");
	data2 <- matrix(ncol=6, nrow=1);
	i <- 1;
	while ( i <= (nrow(data)-1) ) {
		if (data[i,2] != 0) {i <- i+1;}
		if (data[i,2] == 0 & data[i+1,3] == 1) {
			aux1 <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 1);
			aux2 <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 2);
			data2 <- rbind(data2, aux1, aux2);
		}
		if(data[i,2] == 0 & data[i+1,3] == 3) {
			aux1 <- c(data[i,1], 0, data[i+1,2], 1, data[i,4], 1);
			aux2 <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 2);
			data2 <- rbind(data2, aux1, aux2);
		}
		if (data[i,2] == 0 & (i+2) <= nrow(data) & data[i+1,3] == 2) {
			if (data[i+2,3] == 2) {
				aux1 <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 1);
				aux2 <- c(data[i,1], 0, data[i+1,2], 1, data[i,4], 2);
				aux3 <- c(data[i,1], data[i+1,2], data[i+2,2], 0, data[i,4], 3);
				data2 <- rbind(data2, aux1, aux2, aux3);
			}
			if (data[i+2,3] == 3) {
				aux1 <- c(data[i,1], 0, data[i+1,2], 0, data[i,4], 1);
				aux2 <- c(data[i,1], 0, data[i+1,2], 1, data[i,4], 2);
				aux3 <- c(data[i,1], data[i+1,2], data[i+2,2], 1, data[i,4], 3);
				data2 <- rbind(data2, aux1, aux2, aux3);
			}
		}
		i <- i+1;
	}
	data2 <- data.frame(data2, row.names=NULL);
	names(data2) <- c("id", "start", "stop", "event", "covariate", "trans");
	data2 <- data2[-1,];
	row.names(data2) <- as.integer( 1:nrow(data2) );
	class(data2) <- c(class(data2), "CMM");
	return(data2);
} # as.CMM.THMM

\encoding{UTF-8}
\name{genTDCM}
\alias{genTDCM}
\title{Generating data from a Cox model with time-dependent covariates}
\description{Generating data from a Cox model with time-dependent covariates.}
\usage{genTDCM(n, dist, corr, dist.par, model.cens, cens.par, beta, lambda)}

\arguments{
\item{n}{Sample size.}
\item{dist}{
	Bivariate distribution assumed for generating the two covariates (time-fixed and time-dependent).
	Possible bivariate distributions are "exponential" and "weibull" (see details below).
}
\item{corr}{
	Correlation parameter. Possible values for the bivariate exponential distribution
	are between -1 and 1 (0 for independency). Any value between 0 (not included)
	and 1 (1 for independency) is accepted for the bivariate weibull distribution.
}
\item{dist.par}{
	Vector of parameters for the allowed distributions. Two (scale) parameters for the
	bivariate exponential distribution and four (2 shape parameters and 2 scale
	parameters) for the bivariate weibull distribution: (shape1, scale1, shape2, scale2). See details below.
}
\item{model.cens}{Model for censorship. Possible values are "uniform" and "exponential".}
\item{cens.par}{Parameter for the censorship distribution. Must be greater than 0.}
\item{beta}{Vector of two regression parameters for the two covariates.}
\item{lambda}{Parameter for an exponential distribution. An exponential distribution is assumed for the baseline hazard function.}
}

\details{
The bivariate exponential distribution, also known as Farlie-Gumbel-Morgenstern distribution is given by
\deqn{F(x,y)=F_1(x)F_2(y)[1+\alpha(1-F_1(x))(1-F_2(y))]}{F(x,y)=F_1(x)F_2(y)[1+\alpha(1-F_1(x))(1-F_2(y))]}
for \eqn{x\ge0}{x\ge0} and \eqn{y\ge0}{y\ge0}. Where the marginal distribution functions \eqn{F_1}{F_1} and \eqn{F_2}{F_2} are exponential with scale parameters \eqn{\theta_1}{\theta_1} and \eqn{\theta_2}{\theta_2} and correlation parameter \eqn{\alpha}{\alpha}, \eqn{-1 \le \alpha \le 1}{-1 \le \alpha \le 1}. \cr

The bivariate Weibull distribution with two-parameter marginal distributions. It's survival function is given by
\deqn{S(x,y)=P(X>x,Y>y)=e^{-[(\frac{x}{\theta_1})^\frac{\beta_1}{\delta}+(\frac{y}{\theta_2})^\frac{\beta_2}{\delta}]^\delta}}{S(x,y)=P(X>x,Y>y)=exp^(-[(x/\theta_1)^(\beta_1/\delta)+(y/\theta_2)^(\beta_2/\delta)]^\delta)}

Where \eqn{0 < \delta \le 1}{0 < \delta \le 1} and each marginal distribution has shape parameter \eqn{\beta_i}{\beta_i} and a scale parameter \eqn{\theta_i}{\theta_i}, \eqn{i = 1, 2}.
}

\value{
An object with two classes, \code{data.frame} and \code{TDCM}.
To accommodate time-dependent effects, we used a counting process data-structure, introduced by Andersen and Gill (1982).
In this data-structure, apart the time-fixed covariates (named \code{covariate}), an individual's survival data is expressed by three variables:
\code{start}, \code{stop} and \code{event}. Individuals without change in the time-dependent covariate (named \code{tdcov}) are represented by only one line of data,
whereas patients with a change in the time-dependent covariate must be represented by two lines.
For these patients, the first line represents the time period until the change in the time-dependent covariate;
the second line represents the time period that passes from that change to the end of the follow-up.
For each line of data, variables \code{start} and \code{stop} mark the time interval (start, stop) for the data,
while event is an indicator variable taking on value 1 if there was a death at time stop, and 0 otherwise.
More details about this data-structure can be found in papers by (Meira-Machado et al., 2009).
}

\references{
Anderson, P.K., Gill, R.D. (1982). Cox's regression model for counting processes: a large sample study. \emph{Annals of Statistics}, \bold{10}(4), 1100-1120. \doi{10.1214/aos/1176345976}

Cox, D.R. (1972). Regression models and life tables. \emph{Journal of the Royal Statistical Society: Series B}, \bold{34}(2), 187-202. \doi{10.1111/j.2517-6161.1972.tb00899.x}

Johnson, M. E. (1987). \emph{Multivariate Statistical Simulation}, John Wiley and Sons.

Johnson, N., Kotz, S. (1972). \emph{Distribution in statistics: continuous multivariate distributions}, John Wiley and Sons.

Lu J., Bhattacharya G. (1990). Some new constructions of bivariate weibull models. \emph{Annals of Institute of Statistical Mathematics}, \bold{42}(3), 543-559. \doi{10.1007/BF00049307}

Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. \emph{Statistical Methods in Medical Research}, \bold{18}(2), 195-222. \doi{10.1177/0962280208092301}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}

Therneau, T.M., Grambsch, P.M. (2000). \emph{Modelling survival data: Extending the Cox Model}, New York: Springer.
}

\author{Artur Araújo, Luís Meira Machado and Susana Faria}

%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{genCMM}},
\code{\link{genCPHM}},
\code{\link{genTHMM}}.
}

\examples{
tdcmdata <- genTDCM(n=1000, dist="weibull", corr=0.8, dist.par=c(2,3,2,3),
model.cens="uniform", cens.par=2.5, beta=c(-3.3,4), lambda=1)
head(tdcmdata, n=20L)
library(survival)
fit1<-coxph(Surv(start,stop,event)~tdcov+covariate,data=tdcmdata)
summary(fit1)

tdcmdata2 <- genTDCM(n=1000, dist="exponential", corr=0, dist.par=c(1,1),
model.cens="uniform", cens.par=1, beta=c(-3,2), lambda=0.5)
head(tdcmdata2, n=20L)
fit2<-coxph(Surv(start,stop,event)~tdcov+covariate,data=tdcmdata2)
summary(fit2)
}

\keyword{datagen}
\keyword{survival}

\encoding{UTF-8}
\name{as.THMM}
\alias{as.THMM}
\alias{is.THMM}
\title{Coerce to an object of class \code{THMM}}
\description{Function to coerce objects of class \code{CMM} and \code{TDCM} to objects of class \code{THMM}.}
\usage{as.THMM(x)
is.THMM(x)}

\arguments{
\item{x}{Any R object.}
}

%\details{
%}

\value{An object with two classes one being \code{data.frame} and the other \code{THMM}.}

\references{
Cox, D.R. (1972). Regression models and life tables. \emph{Journal of the Royal Statistical Society: Series B}, \bold{34}(2), 187-202. \doi{10.1111/j.2517-6161.1972.tb00899.x}

Jackson, C. (2011). Multi-State Models for Panel Data: The msm Package for R. \emph{Journal of Statistical Software}, \bold{38}(8), 1–28. \doi{10.18637/jss.v038.i08}

Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. \emph{Statistical Methods in Medical Research}, \bold{18}(2), 195-222. \doi{10.1177/0962280208092301}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Roca-Pardiñas, J. (2011). p3state.msm: Analyzing Survival Data from an Illness-Death Model. \emph{Journal of Statistical Software}, \bold{38}(3), 1-18. \doi{10.18637/jss.v038.i03}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}

Therneau, T.M., Grambsch, P.M. (2000). \emph{Modelling survival data: Extending the Cox Model}, New York: Springer.
}

\author{Artur Araújo, Luís Meira Machado and Susana Faria}

%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{as.CMM}},
\code{\link{as.TDCM}},
\code{\link{genCMM}},
\code{\link{genTDCM}},
\code{\link{genTHMM}}.
}

\examples{
# generate CMM data
cmmdata <- genCMM( n=1000, model.cens="uniform", cens.par=2.5, beta=c(2,1,-1),
covar=10, rate=c(1,5,1,5,1,5) )

# coerce CMM data to THMM data
thmmdata0 <- as.THMM(cmmdata)
head(thmmdata0, n=20L)

# generate TDCM data
tdcmdata <- genTDCM(n=100, dist="exponential", corr=0, dist.par=c(1,1),
model.cens="uniform", cens.par=1, beta=c(-3,2), lambda=10)

# coerce TDCM data to THMM data
thmmdata1 <- as.THMM(tdcmdata)
head(thmmdata1, n=20L)
}

\keyword{manip}
\keyword{methods}
\keyword{survival}

\encoding{UTF-8}
\name{genCPHM}
\alias{genCPHM}
\title{Generation of survival data from a Cox Proportional Hazard Model}
\description{Generation of survival data from a Cox Proportional Hazard Model.}
\usage{genCPHM(n, model.cens, cens.par, beta, covar)}

\arguments{
\item{n}{Sample size.}
\item{model.cens}{Model for censorship. Possible values are "uniform" and "exponential".}
\item{cens.par}{Parameter for the censorship distribution. Must be greater than 0.}
\item{beta}{Regression parameter for the time-fixed covariate.}
\item{covar}{Parameter for generating the time-fixed covariate. An uniform distribution is used.}
}

%\details{
%}

\value{An object with two classes, \code{data.frame} and \code{CPHM}.}

\references{
Cox, D.R. (1972). Regression models and life tables. \emph{Journal of the Royal Statistical Society: Series B}, \bold{34}(2), 187-202. \doi{10.1111/j.2517-6161.1972.tb00899.x}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}
}

\author{Artur Araújo, Luís Meira Machado and Susana Faria}

%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{genCMM}},
\code{\link{genTDCM}},
\code{\link{genTHMM}}.
}

\examples{
cphmdata <- genCPHM(n=1000, model.cens="exponential", cens.par=2, beta= 2, covar=1)
head(cphmdata, n=20L)
library(survival)
fit<-coxph(Surv(time,status)~covariate,data=cphmdata)
summary(fit)
}

\keyword{datagen}
\keyword{survival}

\encoding{UTF-8}
\name{genTHMM}
\alias{genTHMM}
\title{Generation of survival data from a time-homogeneous Markov model}
\description{Generation of survival data from a time-homogeneous Markov model.}
\usage{genTHMM(n, model.cens, cens.par, beta, covar, rate)}

\arguments{
\item{n}{Sample size.}
\item{model.cens}{Model for censorship. Possible values are "uniform" and "exponential".}
\item{cens.par}{Parameter for the censorship distribution. Must be greater than 0.}
\item{beta}{Vector of three regression parameters for the three transitions: (beta_12,beta_13,beta_23).}
\item{covar}{Parameter for generating the time-fixed covariate. An uniform distribution is used.}
\item{rate}{Vector of dimension three. We assume an exponential baseline hazard function with constant hazard rate for each transition.}
}

%\details{
%}

\value{
An object with two classes, \code{data.frame} and \code{THMM}.
For generating survival data from the THMM model, the counting process data structure must contain the following variables:
\code{id}, \code{time}, \code{state}, \code{covariate}. Each patient is identified by id.
The variable \code{time} represents time for each interval of follow-up while variable \code{state} denotes the state of the individual.
Variable \code{covariate} is the (time-fixed) covariate to be studied in the regression model.
Individuals without change in the time dependent covariate are represented by two lines of data,
whereas patients with a change in the time-dependent covariate must be represented by three lines.
}

\references{
Jackson, C. (2011). Multi-State Models for Panel Data: The msm Package for R. \emph{Journal of Statistical Software}, \bold{38}(8), 1–28. \doi{10.18637/jss.v038.i08}

Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. \emph{Statistical Methods in Medical Research}, \bold{18}(2), 195-222. \doi{10.1177/0962280208092301}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}

Therneau, T.M., Grambsch, P.M. (2000). \emph{Modelling survival data: Extending the Cox Model}, New York: Springer.
}

\author{Artur Araújo, Luís Meira Machado and Susana Faria}

%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{genCMM}},
\code{\link{genTDCM}},
\code{\link{genCPHM}}.
}

\examples{
thmmdata <- genTHMM( n=100, model.cens="uniform", cens.par=80, beta= c(0.09,0.08,-0.09),
covar=80, rate= c(0.05,0.04,0.05) )
head(thmmdata, n=20L)
}

\keyword{datagen}
\keyword{survival}

\encoding{UTF-8}
\name{genCMM}
\alias{genCMM}
\title{Generation of Cox Markov data from an illness-death model}
\description{Generation of Cox Markov data from an illness-death model.}
\usage{genCMM(n, model.cens, cens.par, beta, covar, rate)}

\arguments{
\item{n}{Sample size.}
\item{model.cens}{Model for censorship. Possible values are "uniform" and "exponential".}
\item{cens.par}{Parameter for the censorship distribution. Must be greater than 0.}
\item{beta}{Vector of three regression parameters for the three transitions: (beta_12,beta_13,beta_23).}
\item{covar}{Parameter for generating the time-fixed covariate. An uniform distribution is used.}
\item{rate}{
	Vector of dimension six: (shape1, scale1, shape2, scale2, shape3, scale3).
	A Weibull baseline hazard function is assumed (with two parameters) for each transition (see details below).}
}

\details{
The Weibull distribution with shape parameter \eqn{\lambda} and scale parameter \eqn{\theta} has hazard function given by:

\deqn{\alpha(t)=\lambda\theta t^{\theta-1}}
}

\value{
An object with two classes, \code{data.frame} and \code{CMM}.
The data structure used for generating survival data from the Cox Markov Model (CMM) is similar as for the time-dependent Cox model (TDCM).
In this case the data structure has one more variable representing the transition (variable \code{trans}).
\code{trans=1} denotes the transition from State 1 to State 3 (without observing the intermediate event; State 2);
\code{trans=2} denotes the transition from State 1 to State 2; and \code{trans=3} denotes the transition from State 2 to State 3 (absorbing).
}

\references{
Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. \emph{Statistical Methods in Medical Research}, \bold{18}(2), 195-222. \doi{10.1177/0962280208092301}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Roca-Pardiñas, J. (2011). p3state.msm: Analyzing Survival Data from an Illness-Death Model. \emph{Journal of Statistical Software}, \bold{38}(3), 1-18. \doi{10.18637/jss.v038.i03}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}

Therneau, T.M., Grambsch, P.M. (2000). \emph{Modelling survival data: Extending the Cox Model}, New York: Springer.
}

\author{Artur Araújo, Luís Meira Machado and Susana Faria}

%\note{
%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{genCPHM}},
\code{\link{genTDCM}},
\code{\link{genTHMM}}.
}

\examples{
cmmdata <- genCMM( n=1000, model.cens="uniform", cens.par=2.5, beta=c(2,1,-1),
covar=10, rate=c(1,5,1,5,1,5) )
head(cmmdata, n=20L)
library(survival)
fit_13<-coxph(Surv(start,stop,event)~covariate, data=cmmdata, subset=c(trans==1))
fit_13
fit_12<-coxph(Surv(start,stop,event)~covariate, data=cmmdata, subset=c(trans==2))
fit_12
fit_23<-coxph(Surv(start,stop,event)~covariate, data=cmmdata, subset=c(trans==3))
fit_23
}

\keyword{datagen}
\keyword{survival}

\encoding{UTF-8}
\name{genSurv-package}
\alias{genSurv-package}
\docType{package}
\title{Generating Multi-State Survival Data}
\description{
The \pkg{genSurv} software permits to generate data with one binary time-dependent covariate and data stemming from a progressive illness-death model.
}

\details{
	\tabular{ll}{
		Package: \tab genSurv\cr
		Type: \tab Package\cr
		Version: \tab 1.0.6\cr
		Date: \tab 2026-04-05\cr
		License: \tab GPL-3\cr
		LazyLoad: \tab yes\cr
	}
}

\author{
Artur Araújo, Luís Meira-Machado \email{lmachado@math.uminho.pt}\cr
and Susana Faria \email{sfaria@math.uminho.pt}\cr
Maintainer: Artur Araújo \email{artur.stat@gmail.com}
}

\references{
Anderson, P.K., Gill, R.D. (1982). Cox's regression model for counting processes: a large sample study. \emph{Annals of Statistics}, \bold{10}(4), 1100-1120. \doi{10.1214/aos/1176345976}

Cox, D.R. (1972). Regression models and life tables. \emph{Journal of the Royal Statistical Society: Series B}, \bold{34}(2), 187-202. \doi{10.1111/j.2517-6161.1972.tb00899.x}

Jackson, C. (2011). Multi-State Models for Panel Data: The msm Package for R. \emph{Journal of Statistical Software}, \bold{38}(8), 1–28. \doi{10.18637/jss.v038.i08}

Johnson, M. E. (1987). \emph{Multivariate Statistical Simulation}, John Wiley and Sons.

Johnson, N., Kotz, S. (1972). \emph{Distribution in statistics: continuous multivariate distributions}, John Wiley and Sons.

Lu J., Bhattacharya G. (1990). Some new constructions of bivariate weibull models. \emph{Annals of Institute of Statistical Mathematics}, \bold{42}(3), 543-559. \doi{10.1007/BF00049307}

Meira-Machado, L., Cadarso-Suárez, C., De Uña- Álvarez, J., Andersen, P.K. (2009). Multi-state models for the analysis of time to event data. \emph{Statistical Methods in Medical Research}, \bold{18}(2), 195-222. \doi{10.1177/0962280208092301}

Meira-Machado L., Faria S. (2014). A simulation study comparing modeling approaches in an illness-death multi-state model. \emph{Communications in Statistics - Simulation and Computation}, \bold{43}(5), 929-946. \doi{10.1080/03610918.2012.718841}

Meira-Machado, L., Roca-Pardiñas, J. (2011). p3state.msm: Analyzing Survival Data from an Illness-Death Model. \emph{Journal of Statistical Software}, \bold{38}(3), 1-18. \doi{10.18637/jss.v038.i03}

Meira-Machado, L., Sestelo M. (2019). Estimation in the progressive illness-death model: a nonexhaustive
review. \emph{Biometrical Journal}, \bold{61}(2), 245–263. \doi{10.1002/bimj.201700200}

Therneau, T.M., Grambsch, P.M. (2000). \emph{Modelling survival data: Extending the Cox Model}, New York: Springer.
}

\keyword{package}
